@@ -276,12 +276,9 @@ def exists_in_path(filename):
 def exe_exists(pathname):
     """Returns boolean whether executable exists"""
     if os.path.isabs(pathname):
-        if not os.path.exists(pathname):
-            return False
+        return os.path.exists(pathname)
     else:
-        if not exists_in_path(pathname):
-            return False
-    return True
+        return exists_in_path(pathname)
 
 
 def execute_sqlite3(path, cmds):
@@ -321,8 +318,10 @@ def free_space(pathname):
     if 'nt' == os.name:
         import ctypes
         free_bytes = ctypes.c_int64()
-        ctypes.windll.kernel32.GetDiskFreeSpaceExW(unicode(pathname),
-                                                   ctypes.byref(free_bytes), None, None)
+        rc = ctypes.windll.kernel32.GetDiskFreeSpaceExW(unicode(pathname),
+                                                        ctypes.byref(free_bytes), None, None)
+        if 0 == rc:
+            raise ctypes.WinError()
         return free_bytes.value
     mystat = os.statvfs(pathname)
     return mystat.f_bfree * mystat.f_bsize
