@@ -2,23 +2,22 @@
 # -*- coding: UTF-8 -*-
 
 
-## BleachBit
-## Copyright (C) 2013 Andrew Ziem
-## http://bleachbit.sourceforge.net
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+# BleachBit
+# Copyright (C) 2014 Andrew Ziem
+# http://bleachbit.sourceforge.net
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 """
@@ -46,34 +45,38 @@ LOCATIONS_CUSTOM = 2
 
 
 class PreferencesDialog:
+
     """Present the preferences dialog and save changes"""
 
     def __init__(self, parent):
         self.parent = parent
-        self.dialog = gtk.Dialog(title = _("Preferences"), \
-            parent = parent, \
-            flags = gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
+        self.dialog = gtk.Dialog(title=_("Preferences"),
+                                 parent=parent,
+                                 flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
         self.dialog.set_default_size(300, 200)
 
         notebook = gtk.Notebook()
         notebook.append_page(self.__general_page(), gtk.Label(_("General")))
-        notebook.append_page(self.__locations_page(LOCATIONS_CUSTOM), gtk.Label(_("Custom")))
+        notebook.append_page(self.__locations_page(
+            LOCATIONS_CUSTOM), gtk.Label(_("Custom")))
         notebook.append_page(self.__drives_page(), gtk.Label(_("Drives")))
         if 'posix' == os.name:
-            notebook.append_page(self.__languages_page(), gtk.Label(_("Languages")))
-        notebook.append_page(self.__locations_page(LOCATIONS_WHITELIST), gtk.Label(_("Whitelist")))
+            notebook.append_page(
+                self.__languages_page(), gtk.Label(_("Languages")))
+        notebook.append_page(self.__locations_page(
+            LOCATIONS_WHITELIST), gtk.Label(_("Whitelist")))
 
         self.dialog.vbox.pack_start(notebook, True)
         self.dialog.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
 
-
     def __toggle_callback(self, cell, path):
         """Callback function to toggle option"""
         options.toggle(path)
         if online_update_notification_enabled:
             self.cb_beta.set_sensitive(options.get('check_online_updates'))
             if 'nt' == os.name:
-                self.cb_winapp2.set_sensitive(options.get('check_online_updates'))
+                self.cb_winapp2.set_sensitive(
+                    options.get('check_online_updates'))
         if 'auto_start' == path:
             if 'nt' == os.name:
                 swc = Windows.start_with_computer
@@ -84,13 +87,12 @@ class PreferencesDialog:
             except:
                 traceback.print_exc()
                 dlg = gtk.MessageDialog(self.parent,
-                    type = gtk.MESSAGE_ERROR,
-                    buttons = gtk.BUTTONS_OK,
-                    message_format = str(sys.exc_info()[1]))
+                                        type=gtk.MESSAGE_ERROR,
+                                        buttons=gtk.BUTTONS_OK,
+                                        message_format=str(sys.exc_info()[1]))
                 dlg.run()
                 dlg.destroy()
 
-
     def __general_page(self):
         """Return a widget containing the general page"""
 
@@ -104,10 +106,13 @@ class PreferencesDialog:
         vbox = gtk.VBox()
 
         if online_update_notification_enabled:
-            cb_updates = gtk.CheckButton(_("Check periodically for software updates via the Internet"))
+            cb_updates = gtk.CheckButton(
+                _("Check periodically for software updates via the Internet"))
             cb_updates.set_active(options.get('check_online_updates'))
-            cb_updates.connect('toggled', self.__toggle_callback, 'check_online_updates')
-            cb_updates.set_tooltip_text(_("If an update is found, you will be given the option to view information about it.  Then, you may manually download and install the update."))
+            cb_updates.connect(
+                'toggled', self.__toggle_callback, 'check_online_updates')
+            cb_updates.set_tooltip_text(
+                _("If an update is found, you will be given the option to view information about it.  Then, you may manually download and install the update."))
             vbox.pack_start(cb_updates, False)
 
             updates_box = gtk.VBox()
@@ -116,14 +121,18 @@ class PreferencesDialog:
             self.cb_beta = gtk.CheckButton(_("Check for new beta releases"))
             self.cb_beta.set_active(options.get('check_beta'))
             self.cb_beta.set_sensitive(options.get('check_online_updates'))
-            self.cb_beta.connect('toggled', self.__toggle_callback, 'check_beta')
+            self.cb_beta.connect(
+                'toggled', self.__toggle_callback, 'check_beta')
             updates_box.pack_start(self.cb_beta, False)
 
             if 'nt' == os.name:
-                self.cb_winapp2 = gtk.CheckButton(_("Download and update cleaners from community (winapp2.ini)"))
+                self.cb_winapp2 = gtk.CheckButton(
+                    _("Download and update cleaners from community (winapp2.ini)"))
                 self.cb_winapp2.set_active(options.get('update_winapp2'))
-                self.cb_winapp2.set_sensitive(options.get('check_online_updates'))
-                self.cb_winapp2.connect('toggled', self.__toggle_callback, 'update_winapp2')
+                self.cb_winapp2.set_sensitive(
+                    options.get('check_online_updates'))
+                self.cb_winapp2.connect(
+                    'toggled', self.__toggle_callback, 'update_winapp2')
                 updates_box.pack_start(self.cb_winapp2, False)
 
             vbox.pack_start(updates_box, False)
@@ -134,7 +143,8 @@ class PreferencesDialog:
         cb_shred = gtk.CheckButton(_("Overwrite files to hide contents"))
         cb_shred.set_active(options.get('shred'))
         cb_shred.connect('toggled', self.__toggle_callback, 'shred')
-        cb_shred.set_tooltip_text(_("Overwriting is ineffective on some file systems and with certain BleachBit operations.  Overwriting is significantly slower."))
+        cb_shred.set_tooltip_text(
+            _("Overwriting is ineffective on some file systems and with certain BleachBit operations.  Overwriting is significantly slower."))
         vbox.pack_start(cb_shred, False)
 
         cb_start = gtk.CheckButton(_("Start BleachBit with computer"))
@@ -149,14 +159,13 @@ class PreferencesDialog:
         def add_drive_cb(button):
             """Callback for adding a drive"""
             title = _("Choose a folder")
-            pathname = GuiBasic.browse_folder(self.parent, title, \
-                multiple = False, stock_button = gtk.STOCK_ADD)
+            pathname = GuiBasic.browse_folder(self.parent, title,
+                                              multiple=False, stock_button=gtk.STOCK_ADD)
             if pathname:
                 liststore.append([pathname])
                 pathnames.append(pathname)
                 options.set_list('shred_drives', pathnames)
 
-
         def remove_drive_cb(button):
             """Callback for removing a drive"""
             treeselection = treeview.get_selection()
@@ -169,11 +178,11 @@ class PreferencesDialog:
             pathnames.remove(pathname)
             options.set_list('shred_drives', pathnames)
 
-
         vbox = gtk.VBox()
 
         # TRANSLATORS: 'free' means 'unallocated'
-        notice = gtk.Label(_("Choose a writable folder for each drive for which to overwrite free space."))
+        notice = gtk.Label(
+            _("Choose a writable folder for each drive for which to overwrite free space."))
         notice.set_line_wrap(True)
         vbox.pack_start(notice, False)
 
@@ -186,17 +195,19 @@ class PreferencesDialog:
             pathnames = []
         for pathname in pathnames:
             liststore.append([pathname])
-        treeview = gtk.TreeView(model = liststore)
+        treeview = gtk.TreeView(model=liststore)
         crt = gtk.CellRendererText()
-        tvc = gtk.TreeViewColumn(None, crt, text = 0)
+        tvc = gtk.TreeViewColumn(None, crt, text=0)
         treeview.append_column(tvc)
 
         vbox.pack_start(treeview)
 
-        # TRANSLATORS: In the preferences dialog, this button adds a path to the list of paths
+        # TRANSLATORS: In the preferences dialog, this button adds a path to
+        # the list of paths
         button_add = gtk.Button(_p('button', 'Add'))
         button_add.connect("clicked", add_drive_cb)
-        # TRANSLATORS: In the preferences dialog, this button removes a path from the list of paths
+        # TRANSLATORS: In the preferences dialog, this button removes a path
+        # from the list of paths
         button_remove = gtk.Button(_p('button', 'Remove'))
         button_remove.connect("clicked", remove_drive_cb)
 
@@ -208,7 +219,6 @@ class PreferencesDialog:
 
         return vbox
 
-
     def __languages_page(self):
         """Return widget containing the languages page"""
 
@@ -222,7 +232,8 @@ class PreferencesDialog:
 
         vbox = gtk.VBox()
 
-        notice = gtk.Label(_("All languages will be deleted except those checked."))
+        notice = gtk.Label(
+            _("All languages will be deleted except those checked."))
         vbox.pack_start(notice)
 
         # populate data
@@ -230,7 +241,7 @@ class PreferencesDialog:
         for lang in Unix.locales.iterate_languages():
             preserve = options.get_language(lang)
             native = Unix.locales.native_name(lang)
-            liststore.append( [ preserve, lang, native ] )
+            liststore.append([preserve, lang, native])
 
         # create treeview
         treeview = gtk.TreeView(liststore)
@@ -239,7 +250,8 @@ class PreferencesDialog:
         self.renderer0 = gtk.CellRendererToggle()
         self.renderer0.set_property('activatable', True)
         self.renderer0.connect('toggled', preserve_toggled_cb, liststore)
-        self.column0 = gtk.TreeViewColumn(_("Preserve"), self.renderer0, active=0)
+        self.column0 = gtk.TreeViewColumn(
+            _("Preserve"), self.renderer0, active=0)
         treeview.append_column(self.column0)
 
         self.renderer1 = gtk.CellRendererText()
@@ -259,7 +271,6 @@ class PreferencesDialog:
         vbox.pack_start(swindow, False)
         return vbox
 
-
     def __locations_page(self, page_type):
         """Return a widget containing a list of files and folders"""
 
@@ -272,26 +283,24 @@ class PreferencesDialog:
                     if pathname == this_pathname[1]:
                         print "warning: '%s' already exists in whitelist" % pathname
                         return
-                liststore.append( [ _('File'), pathname ] )
-                pathnames.append( [ 'file', pathname ] )
+                liststore.append([_('File'), pathname])
+                pathnames.append(['file', pathname])
                 options.set_whitelist_paths(pathnames)
 
-
         def add_whitelist_folder_cb(button):
             """Callback for adding a folder"""
             title = _("Choose a folder")
-            pathname = GuiBasic.browse_folder(self.parent, title, \
-                multiple = False, stock_button = gtk.STOCK_ADD)
+            pathname = GuiBasic.browse_folder(self.parent, title,
+                                              multiple=False, stock_button=gtk.STOCK_ADD)
             if pathname:
                 for this_pathname in pathnames:
                     if pathname == this_pathname[1]:
                         print "warning: '%s' already exists in whitelist" % pathname
                         return
-                liststore.append( [ _('Folder'), pathname ] )
-                pathnames.append( [ 'folder', pathname ] )
+                liststore.append([_('Folder'), pathname])
+                pathnames.append(['folder', pathname])
                 options.set_whitelist_paths(pathnames)
 
-
         def remove_whitelist_path_cb(button):
             """Callback for removing a path"""
             treeselection = treeview.get_selection()
@@ -306,9 +315,6 @@ class PreferencesDialog:
                     pathnames.remove(this_pathname)
                     options.set_whitelist_paths(pathnames)
 
-
-
-
         def add_custom_file_cb(button):
             """Callback for adding a file"""
             title = _("Choose a file")
@@ -318,26 +324,24 @@ class PreferencesDialog:
                     if pathname == this_pathname[1]:
                         print "warning: '%s' already exists in whitelist" % pathname
                         return
-                liststore.append( [ _('File'), pathname ] )
-                pathnames.append( [ 'file', pathname ] )
+                liststore.append([_('File'), pathname])
+                pathnames.append(['file', pathname])
                 options.set_custom_paths(pathnames)
 
-
         def add_custom_folder_cb(button):
             """Callback for adding a folder"""
             title = _("Choose a folder")
-            pathname = GuiBasic.browse_folder(self.parent, title, \
-                multiple = False, stock_button = gtk.STOCK_ADD)
+            pathname = GuiBasic.browse_folder(self.parent, title,
+                                              multiple=False, stock_button=gtk.STOCK_ADD)
             if pathname:
                 for this_pathname in pathnames:
                     if pathname == this_pathname[1]:
                         print "warning: '%s' already exists in whitelist" % pathname
                         return
-                liststore.append( [ _('Folder'), pathname ] )
-                pathnames.append( [ 'folder', pathname ] )
+                liststore.append([_('Folder'), pathname])
+                pathnames.append(['folder', pathname])
                 options.set_custom_paths(pathnames)
 
-
         def remove_custom_path_cb(button):
             """Callback for removing a path"""
             treeselection = treeview.get_selection()
@@ -352,7 +356,6 @@ class PreferencesDialog:
                     pathnames.remove(this_pathname)
                     options.set_custom_paths(pathnames)
 
-
         vbox = gtk.VBox()
 
         # load data
@@ -371,13 +374,16 @@ class PreferencesDialog:
             else:
                 raise RuntimeError("Invalid type code: '%s'" % type_code)
             path = paths[1]
-            liststore.append( [ type_str, path ] )
+            liststore.append([type_str, path])
 
         if LOCATIONS_WHITELIST == page_type:
-            # TRANSLATORS: "Paths" is used generically to refer to both files and folders
-            notice = gtk.Label(_("Theses paths will not be deleted or modified."))
+            # TRANSLATORS: "Paths" is used generically to refer to both files
+            # and folders
+            notice = gtk.Label(
+                _("Theses paths will not be deleted or modified."))
         elif LOCATIONS_CUSTOM == page_type:
-            notice = gtk.Label(_("These locations can be selected for deletion."))
+            notice = gtk.Label(
+                _("These locations can be selected for deletion."))
         vbox.pack_start(notice)
 
         # create treeview
@@ -409,14 +415,12 @@ class PreferencesDialog:
         elif LOCATIONS_CUSTOM == page_type:
             button_add_file.connect("clicked", add_custom_file_cb)
 
-
         button_add_folder = gtk.Button(_p('button', 'Add folder'))
         if LOCATIONS_WHITELIST == page_type:
             button_add_folder.connect("clicked", add_whitelist_folder_cb)
         elif LOCATIONS_CUSTOM == page_type:
             button_add_folder.connect("clicked", add_custom_folder_cb)
 
-
         button_remove = gtk.Button(_p('button', 'Remove'))
         if LOCATIONS_WHITELIST == page_type:
             button_remove.connect("clicked", remove_whitelist_path_cb)
@@ -433,10 +437,8 @@ class PreferencesDialog:
         # return page
         return vbox
 
-
     def run(self):
         """Run the dialog"""
         self.dialog.show_all()
         self.dialog.run()
         self.dialog.destroy()
-
