@@ -87,16 +87,16 @@ class Locales:
          'de': 'Deutsch',
          'el': 'Ελληνικά',
          'en': 'English',
-         'en_AU' : 'Australian English',
-         'en_GB' : 'British English',
-         'eo' : 'Esperanto',
+         'en_AU': 'Australian English',
+         'en_GB': 'British English',
+         'eo': 'Esperanto',
          'es': 'Español',
-         'et' : 'eesti',
-         'fa' : 'فارسی',
+         'et': 'eesti',
+         'fa': 'فارسی',
          'fi': 'suomen kieli',
          'fo': 'føroyskt',
          'fr': 'Français',
-         'gl' : 'galego',
+         'gl': 'galego',
          'he': 'עברית',
          'hi': 'हिन्दी',
          'hr': 'Hrvatski',
@@ -144,7 +144,15 @@ class Locales:
                   '/usr/share/gnucash/accounts',
                   '/usr/share/locale/',
                   '/usr/share/speedcrunch/books/',
-                  '/usr/share/vim/vim72/'  # Ubuntu 10.10
+                  '/usr/share/vim/vim72/',  # Ubuntu 10.10
+                  '/usr/share/help/',
+                  '/usr/share/vim/vim74/lang/',
+                  '/usr/share/anki/locale/',
+                  '/usr/share/zenmap/locale/',
+                  '/usr/share/lyx/doc/',
+                  '/usr/share/lyx/examples/',
+                  '/usr/share/lib/R/library/translations',
+                  '/usr/share/cups/doc/',
                   ]
 
     __ignore = ['all_languages', 'C', 'l10n', 'locale.alias', 'default']
