@@ -1,22 +1,21 @@
 # vim: ts=4:sw=4:expandtab
 
-## BleachBit
-## Copyright (C) 2013 Andrew Ziem
-## http://bleachbit.sourceforge.net
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+# BleachBit
+# Copyright (C) 2014 Andrew Ziem
+# http://bleachbit.sourceforge.net
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 """
@@ -24,6 +23,7 @@ Perform the preview or delete operations
 """
 
 
+import math
 import os
 import sys
 import traceback
@@ -34,9 +34,10 @@ from Cleaner import backends
 from Common import _, ungettext
 
 
-
 class Worker:
+
     """Perform the preview or delete operations"""
+
     def __init__(self, ui, really_delete, operations):
         """Create a Worker
 
@@ -56,12 +57,11 @@ class Worker:
         self.total_bytes = 0
         self.total_deleted = 0
         self.total_errors = 0
-        self.total_special = 0 # special operations
+        self.total_special = 0  # special operations
         self.yield_time = None
         if 0 == len(self.operations):
             raise RuntimeError("No work to do")
 
-
     def print_exception(self, operation):
         """Display exception"""
         # TRANSLATORS: This indicates an error.  The special keyword
@@ -69,13 +69,12 @@ class Worker:
         # some other cleaner ID.  The special keyword %(msg)s will be
         # replaced by a message such as 'Permission denied.'
         err = _("Exception while running operation '%(operation)s': '%(msg)s'") \
-            %  { 'operation': operation, 'msg' : str(sys.exc_info()[1]) }
+            % {'operation': operation, 'msg': str(sys.exc_info()[1])}
         print err
         traceback.print_exc()
         self.ui.append_text(err + "\n", 'error')
         self.total_errors += 1
 
-
     def execute(self, cmd):
         """Execute or preview the command"""
         ret = None
@@ -109,14 +108,12 @@ class Worker:
                 path = ret['path']
             else:
                 path = ''
-            path = path.decode('utf8', 'replace') # for invalid encoding
+            path = path.decode('utf8', 'replace')  # for invalid encoding
             line = u"%s %s %s\n" % (ret['label'], size, path)
             self.total_deleted += ret['n_deleted']
             self.total_special += ret['n_special']
             self.ui.append_text(line)
 
-
-
     def clean_operation(self, operation):
         """Perform a single cleaning operation"""
         operation_options = self.operations[operation]
@@ -156,11 +153,50 @@ class Worker:
                 if '' == ds['path']:
                     ds['path'] = os.path.expanduser('~')
                 if 'delete' != ds['command']:
-                    raise NotImplementedError('Deep scan only supports deleting now')
+                    raise NotImplementedError(
+                        'Deep scan only supports deleting now')
                 if not self.deepscans.has_key(ds['path']):
                     self.deepscans[ds['path']] = []
                 self.deepscans[ds['path']].append(ds)
 
+    def run_delayed_op(self, operation, option_id):
+        """Run one delayed operation"""
+        self.ui.update_progress_bar(0.0)
+        if 'free_disk_space' == option_id:
+            # TRANSLATORS: 'free' means 'unallocated'
+            msg = _("Please wait.  Wiping free disk space.")
+        elif 'memory' == option_id:
+            msg = _("Please wait.  Cleaning %s.") % _("Memory")
+        else:
+            raise RuntimeError("Unexpected option_id in delayed ops")
+        self.ui.update_progress_bar(msg)
+        for cmd in backends[operation].get_commands(option_id):
+            old_phase = None
+            for ret in self.execute(cmd):
+                if isinstance(ret, tuple):
+                    # Display progress (for free disk space)
+                    phase = ret[
+                        0]  # 1=wipe free disk space, 2=wipe inodes, 3=clean up inodes files
+                    percent_done = ret[1]
+                    eta_seconds = ret[2]
+                    self.ui.update_progress_bar(percent_done)
+                    if phase == 2:
+                        msg = _('Please wait. Wiping file system metadata.')
+                    elif phase == 3:
+                        msg = _(
+                            'Please wait. Cleaning up after wiping file system metadata.')
+                    if isinstance(eta_seconds, int):
+                        eta_mins = math.ceil(eta_seconds / 60)
+                        msg2 = ungettext("About %d minute remaining.",
+                                         "About %d minutes remaining.", eta_mins) \
+                            % eta_mins
+                        self.ui.update_progress_bar(msg + ' ' + msg2)
+                    else:
+                        self.ui.update_progress_bar(msg)
+                if True == ret or isinstance(ret, tuple):
+                    # Return control to PyGTK idle loop to keep
+                    # it responding and allow the user to abort.
+                    yield True
 
     def run(self):
         """Perform the main cleaning process which has these phases
@@ -182,8 +218,8 @@ class Worker:
                     priority = 99
                     if 'free_disk_space' == delayable:
                         priority = 100
-                    new_op = (priority, { operation : [ delayable ] } )
-                    self.delayed_ops.append( new_op )
+                    new_op = (priority, {operation: [delayable]})
+                    self.delayed_ops.append(new_op)
 
         # standard operations
         for dummy in self.run_operations(self.operations):
@@ -199,41 +235,20 @@ class Worker:
         for op in sorted(self.delayed_ops):
             operation = op[1].keys()[0]
             for option_id in op[1].values()[0]:
-                self.ui.update_progress_bar(0.0)
-                if 'free_disk_space' == option_id:
-                    # TRANSLATORS: 'free' means 'unallocated'
-                    msg = _("Please wait.  Wiping free disk space.")
-                elif 'memory' == option_id:
-                    msg = _("Please wait.  Cleaning %s.") % _("Memory")
-                else:
-                    raise RuntimeError("Unexpected option_id in delayed ops")
-                self.ui.update_progress_bar(msg)
-                for cmd in backends[operation].get_commands(option_id):
-                    for ret in self.execute(cmd):
-                        if isinstance(ret, tuple):
-                            # Display progress (for free disk space)
-                            self.ui.update_progress_bar(ret[0])
-                            mins = int(ret[1] / 60)
-                            msg2 = ungettext("About %d minute remaining.", \
-                                "About %d minutes remaining.", mins) \
-                                % mins
-                            self.ui.update_progress_bar(msg + ' ' + msg2)
-                        if True == ret or isinstance(ret, tuple):
-                            # Return control to PyGTK idle loop to keep
-                            # it responding and allow the user to abort.
-                            yield True
-
+                for ret in self.run_delayed_op(operation, option_id):
+                    # yield to GTK+ idle loop
+                    yield True
 
         # print final stats
         bytes_delete = FileUtilities.bytes_to_human(self.total_bytes)
         if self.really_delete:
             # TRANSLATORS: This refers to disk space that was
             # really recovered (in other words, not a preview)
-            line =  _("Disk space recovered: %s") % bytes_delete
+            line = _("Disk space recovered: %s") % bytes_delete
         else:
             # TRANSLATORS: This refers to a preview (no real
             # changes were made yet)
-            line =  _("Disk space to be recovered: %s") % bytes_delete
+            line = _("Disk space to be recovered: %s") % bytes_delete
         self.ui.append_text("\n%s" % line)
         if self.really_delete:
             # TRANSLATORS: This refers to the number of files really
@@ -245,7 +260,7 @@ class Worker:
             line = _("Files to be deleted: %d") % self.total_deleted
         self.ui.append_text("\n%s" % line)
         if self.total_special > 0:
-            line =  _("Special operations: %d") % self.total_special
+            line = _("Special operations: %d") % self.total_special
             self.ui.append_text("\n%s" % line)
         if self.total_errors > 0:
             line = _("Errors: %d") % self.total_errors
@@ -257,7 +272,6 @@ class Worker:
 
         yield False
 
-
     def run_deep_scan(self):
         """Run deep scans"""
         print 'debug: deepscans=', self.deepscans
@@ -265,7 +279,7 @@ class Worker:
         # areas of the file system such as the user's whole home directory
         # or all the system executables.
         self.ui.update_progress_bar(_("Please wait.  Running deep scan."))
-        yield True # allow GTK to update the screen
+        yield True  # allow GTK to update the screen
         ds = DeepScan.DeepScan()
         for (path, dsdict) in self.deepscans.iteritems():
             print 'debug: deepscan path=', path
@@ -296,7 +310,7 @@ class Worker:
                 # TRANSLATORS: %s is replaced with Firefox, System, etc.
                 msg = _("Please wait.  Previewing %s.") % name
             self.ui.update_progress_bar(msg)
-            yield True # show the progress bar message now
+            yield True  # show the progress bar message now
             try:
                 for dummy in self.clean_operation(operation):
                     yield True
